@@ -167,7 +167,7 @@ import types
 
 import pkg_resources
 
-VERSION = "1.1.1"
+VERSION = "1.1.2"
 __AUTHOR__ = "Louis Paternault (spalax+python@gresille.org)"
 __COPYRIGHT__ = "(C) 2017-2020 Louis Paternault. GNU GPL 3 or later."
 __all__ = argparse.__all__ + ["ERROR", "IGNORE", "DOUBLE", "RAISE"]
@@ -185,6 +185,8 @@ class _Constants(enum.IntEnum):
     RAISE = enum.auto()
 
     def __repr__(self):
+        # Pylint (2.5.0) is wrong!
+        # pylint: disable=invalid-repr-returned
         return self.name
 
 
@@ -269,7 +271,7 @@ class _SubCommandsDispatch(
     """
 
     def __call__(self, *args, **kwargs):
-        # pylint: disable=arguments-differ
+        # pylint: disable=signature-differs
         if self._name_dispatcher_map.get(args[2][0], None) is not None:
             sys.exit(self._name_dispatcher_map[args[2][0]](args[2][1:]))
         return super().__call__(*args, **kwargs)
@@ -537,11 +539,12 @@ class _SubCommandsDispatch(
         if isinstance(module, types.ModuleType):
             path = module.__path__
             prefix = module.__name__ + "."
-            modulename = module.__name__
         elif isinstance(module, str):
-            path = (os.path.join(pythonpath, module) for pythonpath in sys.path)
+            path = (
+                os.path.join(pythonpath, module.replace(".", "/"))
+                for pythonpath in sys.path
+            )
             prefix = module + "."
-            modulename = module
         else:
             raise TypeError("Argument `module` must be a string or a module.")
         for __finder, name, ispkg in pkgutil.iter_modules(path, prefix):
